# -*- coding: utf-8 -*-
from __future__ import unicode_literals, absolute_import

__version__ = '0.5.2'
__author__ = 'Stefan Foulis'
__license__ = 'BSD'
__copyright__ = "Copyright 2014, Divio Aldryn Ltd"
__maintainer__ = 'Stefan Foulis'
__email__ = 'stefan@foulis.ch'
__url__ = 'https://github.com/aldryn/aldryn-sites/'
__status__ = 'Development'
__doc__ = 'An extension for django.contrib.sites, featuring domain redirects and automatic population of the django.contrib.sites.Site table based on settings.'  # noqa


default_app_config = 'aldryn_sites.apps.AldrynSitesConfig'
