# -*- coding: utf-8 -*-
from __future__ import unicode_literals, absolute_import
from django.apps import AppConfig


class AldrynSitesConfig(AppConfig):
    name = 'aldryn_sites'
    verbose_name = "Aldryn Sites"
